@@ -5,6 +5,7 @@ package Crypt::TEA_PP;
 use strict;
 use warnings;
 use utf8;
+use integer;
 
 use Carp;
 use List::Util qw(all);
@@ -146,7 +147,7 @@ Crypt::TEA_PP - Pure Perl Implementation of the Tiny Encryption Algorithm
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
@@ -156,7 +157,7 @@ version 0.0301
    my $tea = Crypt::TEA_PP->new( $key );
    my $cbc = Crypt::CBC->new( -cipher => $tea );
 
-   my $text = 'The quick brown fox jumps over the lazy dog';
+   my $text = 'The quick brown fox jumps over the lazy dog.';
    my $cipher_text = $cbc->encrypt( $text );
 
    my $plain_text = $cbc->decrypt( $cipher_text );
@@ -182,7 +183,7 @@ Returns the TEA block size, which is 8 bytes. This function exists so that Crypt
 
 =head2 new
 
-    my $tea =  Crypt::TEA_PP->new( $key, $rounds );
+    my $tea = Crypt::TEA_PP->new( $key, $rounds );
 
 This creates a new Crypt::TEA_PP object with the specified key.
 The optional rounds parameter specifies the number of rounds of encryption to perform, and defaults to 32.
